pycbg.preprocessing.Materials
=============================

.. currentmodule:: pycbg.preprocessing

.. autoclass:: Materials
   :members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Materials.__init__
      ~Materials.create_LinearElastic3D
      ~Materials.create_MohrCoulomb3D
      ~Materials.create_Newtonian3D
   
   

   
   
   